# Copyright 2023 The triangulate Authors.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

"""Main binary."""

from collections.abc import Sequence

from absl import app
from absl import flags

from triangulate.testdata.multifile_example import library_b

_LENGTH = flags.DEFINE_integer("length", 0, "Length of input sequence.")


def main(argv: Sequence[str]) -> None:
  if len(argv) > 1:
    raise app.UsageError("Too many command-line arguments.")
  length = _LENGTH.value
  xs = range(length)
  mean = library_b.mean(xs)
  print(f"Input: {xs}")
  print(f"Mean: {mean}")


if __name__ == "__main__":
  app.run(main)
